---
comments: true
---

# Super Gobang

A backgammon game based on `tkintertools`.

* 🔖 Version: `2.0`
* 📦 Framework: `tkintertools 2.6.21.1`
* ✏️ Author: <https://github.com/Xiaokang2022>
* 🚀 GitHub: <https://github.com/Xiaokang2022/Super-Gobang>

![Watchers](https://img.shields.io/github/watchers/Xiaokang2022/Super-Gobang?label=Watchers&logo=github&style=flat "Watchers")
![Forks](https://img.shields.io/github/forks/Xiaokang2022/Super-Gobang?label=Forks&logo=github&style=flat "Forks")
![Stars](https://img.shields.io/github/stars/Xiaokang2022/Super-Gobang?label=Stars&color=gold&logo=github&style=flat "Stars")
![Issues](https://img.shields.io/github/issues/Xiaokang2022/Super-Gobang?label=Issues&logo=github&style=flat "Issues")
![Pull Requests](https://img.shields.io/github/issues-pr/Xiaokang2022/Super-Gobang?label=Pull%20Requests&logo=github&style=flat "Pull Requests")
![Discussions](https://img.shields.io/github/discussions/Xiaokang2022/Super-Gobang?label=Discussions&logo=github&style=flat "Discussions")

![preview](https://github.com/Xiaokang2022/Super-Gobang/blob/main/preview.png?raw=true)
